@@ -40,7 +40,7 @@
 #'   - `ApplicabilityPlotList`: [list] of plots per (maybe artificial) segment
 #'   - `ReportSummaryTable`: data frame underlying `ApplicabilityPlot`
 #' @export
-#' @importFrom ggplot2 ggplot aes_ geom_tile scale_fill_manual facet_wrap
+#' @importFrom ggplot2 ggplot aes geom_tile scale_fill_manual facet_wrap
 #'                     theme_minimal scale_x_discrete xlab guides
 #'                     guide_legend theme element_text
 #' @examples
@@ -232,9 +232,9 @@ pro_applicability_matrix <- function(study_data, meta_data, split_segments =
   ratio <- dim(app_matrix)[1] / dim(app_matrix)[2]
 
   plot_me <- function(m) {
-    ggplot(m, aes_(
-      x = ~IMPLEMENTATION, y = ~VARIABLES,
-      fill = ~APP_SCORE
+    ggplot(m, aes(
+      x = IMPLEMENTATION, y = VARIABLES,
+      fill = APP_SCORE
     )) +
       geom_tile(colour = "white", lwd = 0.8) +
       scale_fill_manual(values = colcode, name = " ") +
