@@ -3,7 +3,7 @@ library(knitr)
 library(DT)
 knitr::opts_chunk$set(echo = TRUE, message = FALSE, warning = FALSE)
 if (rmarkdown::pandoc_available(version = "1.12.3")) {
-  knit_print.data.frame = function(x, ...) {
+  knit_print.data.frame <- function(x, ...) {
     knit_print(DT::datatable(head(x, 10)), ...)
   }
   registerS3method("knit_print", "data.frame", knit_print.data.frame)
@@ -19,30 +19,36 @@ load(system.file("extdata", "meta_data.RData", package = "dataquieR"))
 md1 <- meta_data
 
 ## ----message=FALSE, warning=FALSE---------------------------------------------
-appmatrix <- pro_applicability_matrix(study_data = sd1, 
-                                      meta_data = md1, 
-                                      label_col = LABEL)
+appmatrix <- pro_applicability_matrix(
+  study_data = sd1,
+  meta_data = md1,
+  label_col = LABEL
+)
 
 ## ----message=FALSE, warning=FALSE, fig.height = 10, fig.width = 6-------------
 appmatrix$ApplicabilityPlot
 
 ## ----message = FALSE, warning = FALSE-----------------------------------------
-my_unit_missings2 <- com_unit_missingness(study_data  = sd1, 
-                                          meta_data   = md1, 
-                                          id_vars     = c("CENTER_0", "PSEUDO_ID"), 
-                                          strata_vars = "CENTER_0", 
-                                          label_col   = "LABEL")
+my_unit_missings2 <- com_unit_missingness(
+  study_data = sd1,
+  meta_data = md1,
+  id_vars = c("CENTER_0", "PSEUDO_ID"),
+  strata_vars = "CENTER_0",
+  label_col = "LABEL"
+)
 
 ## -----------------------------------------------------------------------------
 my_unit_missings2$SummaryData
 
 ## ----message=FALSE, warning=FALSE---------------------------------------------
-MissSegs <- com_segment_missingness(study_data = sd1, 
-                                    meta_data = md1, 
-                                    label_col = "LABEL", 
-                                    threshold_value = 5, 
-                                    direction = "high",
-                                    exclude_roles = c("secondary", "process"))
+MissSegs <- com_segment_missingness(
+  study_data = sd1,
+  meta_data = md1,
+  label_col = "LABEL",
+  threshold_value = 5,
+  direction = "high",
+  exclude_roles = c("secondary", "process")
+)
 
 ## ----message=FALSE, echo=TRUE, warning=FALSE, results = 'hide', fig.keep = 'all',  fig.align="center", fig.height = 3, fig.width = 4----
 MissSegs$SummaryPlot
@@ -56,42 +62,49 @@ sd2 <- sd1
 sd2$month <- month(sd2$v00013)
 
 ## ----message=FALSE, warning=FALSE---------------------------------------------
-MD_TMP <- prep_add_to_meta(VAR_NAMES    = "month",
-                           DATA_TYPE    = "integer",
-                           LABEL        = "EXAM_MONTH",
-                           VALUE_LABELS = "1 = January | 2 = February | 3 = March | 
+MD_TMP <- prep_add_to_meta(
+  VAR_NAMES = "month",
+  DATA_TYPE = "integer",
+  LABEL = "EXAM_MONTH",
+  VALUE_LABELS = "1 = January | 2 = February | 3 = March |
                                           4 = April | 5 = May | 6 = June | 7 = July |
                                           8 = August | 9 = September | 10 = October |
                                           11 = November | 12 = December",
-                           meta_data    = md1)
+  meta_data = md1
+)
 
 ## ----message=FALSE, warning=FALSE---------------------------------------------
-MissSegs <- com_segment_missingness(study_data = sd2, 
-                                    meta_data = MD_TMP, 
-                                    group_vars = "EXAM_MONTH", 
-                                    label_col = "LABEL", 
-                                    threshold_value = 1, 
-                                    direction = "high",
-                                    exclude_roles = c("secondary", "process"))
+MissSegs <- com_segment_missingness(
+  study_data = sd2,
+  meta_data = MD_TMP,
+  group_vars = "EXAM_MONTH",
+  label_col = "LABEL",
+  threshold_value = 1,
+  direction = "high",
+  exclude_roles = c("secondary", "process")
+)
 
 ## ----message=FALSE, echo=TRUE, warning=FALSE, results = 'hide', fig.keep = 'all',  fig.align="center", fig.height = 6, fig.width = 4----
 MissSegs$SummaryPlot
 
 ## ----message=FALSE, warning=FALSE---------------------------------------------
-code_labels <- read.csv2(system.file("extdata", 
-                                     "Missing-Codes-2020.csv", 
-                                     package = "dataquieR"), 
-                         stringsAsFactors = FALSE, na.strings = c())
+code_labels <- read.csv2(system.file("extdata",
+  "Missing-Codes-2020.csv",
+  package = "dataquieR"
+),
+stringsAsFactors = FALSE, na.strings = c()
+)
 
 ## ----message = FALSE, warning = FALSE-----------------------------------------
-item_miss <- com_item_missingness(study_data      = sd1, 
-                                  meta_data       = meta_data, 
-                                  label_col       = 'LABEL', 
-                                  show_causes     = TRUE, 
-                                  cause_label_df  = code_labels,
-                                  include_sysmiss = TRUE, 
-                                  threshold_value = 80
-                                ) 
+item_miss <- com_item_missingness(
+  study_data = sd1,
+  meta_data = meta_data,
+  label_col = "LABEL",
+  show_causes = TRUE,
+  cause_label_df = code_labels,
+  include_sysmiss = TRUE,
+  threshold_value = 80
+)
 
 ## ----message=FALSE, echo=TRUE, warning=FALSE----------------------------------
 item_miss$SummaryTable
@@ -100,11 +113,13 @@ item_miss$SummaryTable
 item_miss$SummaryPlot
 
 ## -----------------------------------------------------------------------------
-MyValueLimits <- con_limit_deviations(resp_vars  = NULL,
-                                      label_col  = "LABEL",
-                                      study_data = sd1,
-                                      meta_data  = md1,
-                                      limits     = "HARD_LIMITS")
+MyValueLimits <- con_limit_deviations(
+  resp_vars = NULL,
+  label_col = "LABEL",
+  study_data = sd1,
+  meta_data = md1,
+  limits = "HARD_LIMITS"
+)
 
 ## ----message=FALSE, echo=TRUE, warning=FALSE----------------------------------
 MyValueLimits$SummaryTable
@@ -114,31 +129,37 @@ MyValueLimits$SummaryTable
 whichdeviate <- as.character(MyValueLimits$SummaryTable$Variables)[MyValueLimits$SummaryTable$GRADING == 1]
 
 ## ----message=FALSE, echo=TRUE, warning=FALSE, results = 'hide', fig.keep = 'all', fig.align="center", fig.height = 3, fig.width = 4----
-ggpubr::ggarrange(plotlist = MyValueLimits$SummaryPlotList[whichdeviate], ncol = 2) 
+ggpubr::ggarrange(plotlist = MyValueLimits$SummaryPlotList[whichdeviate], ncol = 2)
 
 ## ----message=FALSE, warning=FALSE---------------------------------------------
-IAVCatAll <- con_inadmissible_categorical(study_data = sd1, 
-                                          meta_data  = md1, 
-                                          label_col  = "LABEL")
+IAVCatAll <- con_inadmissible_categorical(
+  study_data = sd1,
+  meta_data = md1,
+  label_col = "LABEL"
+)
 
 ## ----message=FALSE, warning=FALSE---------------------------------------------
-checks <- read.csv(system.file("extdata", 
-                               "contradiction_checks.csv",
-                               package = "dataquieR"), 
-                   header = TRUE, sep = "#")
+checks <- read.csv(system.file("extdata",
+  "contradiction_checks.csv",
+  package = "dataquieR"
+),
+header = TRUE, sep = "#"
+)
 
 ## -----------------------------------------------------------------------------
-AnyContradictions <- con_contradictions(study_data      = sd1,
-                                        meta_data       = md1,
-                                        label_col       = "LABEL",
-                                        check_table     = checks,
-                                        threshold_value = 1)
+AnyContradictions <- con_contradictions(
+  study_data = sd1,
+  meta_data = md1,
+  label_col = "LABEL",
+  check_table = checks,
+  threshold_value = 1
+)
 
 ## ----message=FALSE, echo=TRUE, warning=FALSE----------------------------------
 AnyContradictions$SummaryTable
 
 ## ----message=FALSE, echo=TRUE, warning=FALSE, fig.height = 4, fig.width = 6----
-AnyContradictions$SummaryPlot 
+AnyContradictions$SummaryPlot
 
 ## ----echo = TRUE--------------------------------------------------------------
 ruol <- dataquieR:::acc_robust_univariate_outlier(study_data = sd1, meta_data = md1, label_col = LABEL)
@@ -146,12 +167,14 @@ ruol <- dataquieR:::acc_robust_univariate_outlier(study_data = sd1, meta_data =
 ruol$SummaryPlotList
 
 ## ---- fig.height = 3, fig.width = 4-------------------------------------------
-myloess <- dataquieR::acc_loess(resp_vars = "SBP_0",
-                                group_vars = "USR_BP_0",
-                                time_vars = "EXAM_DT_0",
-                                label_col = "LABEL",
-                                study_data = sd1,
-                                meta_data = md1)
+myloess <- dataquieR::acc_loess(
+  resp_vars = "SBP_0",
+  group_vars = "USR_BP_0",
+  time_vars = "EXAM_DT_0",
+  label_col = "LABEL",
+  study_data = sd1,
+  meta_data = md1
+)
 
 myloess$SummaryPlotList
 
